@@ -791,7 +791,7 @@ void KompareListViewLineItem::paintCell(QPainter* p, const QStyleOptionViewItem&
     if (diffItemParent()->isCurrent())
     {
         p->translate(0.5, 0.5);
-        p->setPen(bg.dark(135));
+        p->setPen(bg.darker(135));
         QTreeWidgetItem* parentItem = parent();
         if (this == parentItem->child(0))
             p->drawLine(0, 0, width, 0);
@@ -855,7 +855,11 @@ void KompareListViewLineItem::paintText(QPainter* p, const QColor& bg, int colum
 //                     p->setPen( Qt::black );
                     brush = normalBrush;
                 }
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+                chunkWidth = p->fontMetrics().horizontalAdvance(textChunk);
+#else
                 chunkWidth = p->fontMetrics().width(textChunk);
+#endif
                 p->fillRect(offset, 0, chunkWidth, paintHeight(), brush);
                 p->drawText(offset, 0,
                             chunkWidth, paintHeight(),
@@ -872,7 +876,11 @@ void KompareListViewLineItem::paintText(QPainter* p, const QColor& bg, int colum
             QFont font(p->font());
             font.setBold(false);
             p->setFont(font);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 11, 0)
+            chunkWidth = p->fontMetrics().horizontalAdvance(textChunk);
+#else
             chunkWidth = p->fontMetrics().width(textChunk);
+#endif
             p->fillRect(offset, 0, chunkWidth, paintHeight(), normalBrush);
             p->drawText(offset, 0,
                         chunkWidth, paintHeight(),
